Library for Shelly smart home devices

Features:
- Discover devices
- Monitor status
- Control (turn on/off etc)

Devices supported:
- Shelly 1
- Shelly 2 (relay or roller mode)
- Shelly PLUG
- Shelly BULB (only on/off)
- Shelly RGBWW (only on/off)

Comming soon:
- Shelly 4
- Shelly RGBW2
- Shelly 25
- Shelly PLUG S
- Shelly H&T